- Fix bug #29: Issues with `xoutil.symbols.symbol`:class: documentation and
  implementation.

- Fix bug #30: It was possible to define a dimension with two (or more)
  incompatible canonical units.

- Fix bug #33: Reusing a context leaves the context unusable.

- Renamed ``xoutil.tasking.StandardWait`` to
  `xoutil.tasking.ConstantWait`:class:.
